package com.nh.farm.cloud.business.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.nh.farm.cloud.basic.entity.UserEntity;
import com.nh.farm.cloud.business.domain.dto.SaleCommendInfoDto;
import com.nh.farm.cloud.business.domain.dto.SalePageQuery;
import com.nh.farm.cloud.business.domain.po.SaleCommendInfoPo;
import com.nh.farm.cloud.business.service.OtherDataService;
import com.nh.farm.cloud.business.service.SaleCommendInfoService;
import com.nh.farm.cloud.util.redis.TokenUtil;
import com.nh.fk.common.util.wrapper.WrapMapper;
import com.nh.fk.common.util.wrapper.Wrapper;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.Map;

/**
 * @description: 表扬信
 * @author: suyun
 */
@RestController
@RequestMapping("commend")
public class SaleCommendController {

    @Autowired
    private TokenUtil tokenUtil;

    @Autowired
    private OtherDataService otherDataService;

    @Autowired
    private SaleCommendInfoService saleCommendInfoService;

    /**
     * 汇总
     */
    @GetMapping("/collectInfo")
    public Wrapper<Map<String, Object>> collectInfo(SalePageQuery pageQuery) {
        Map<String, Object> map =  saleCommendInfoService.collectInfo(pageQuery);
        return WrapMapper.ok(map);
    }

    /**
     * 分页
     */
    @GetMapping("/selectInfo")
    public Wrapper<IPage<SaleCommendInfoPo>> selectInfo(SalePageQuery pageQuery) {
        IPage page = saleCommendInfoService.queryPage(pageQuery);
        return WrapMapper.ok(page);
    }

    /**
     * 新增
     */
    @Transactional
    @PostMapping("/saveInfo")
    public Wrapper<String> saveInfo(@RequestBody SaleCommendInfoDto commend){
        SaleCommendInfoPo saleCommendInfoPo = new SaleCommendInfoPo();
        BeanUtils.copyProperties(commend, saleCommendInfoPo);
        UserEntity user = tokenUtil.getUser();
        String phone = user.getPhone();
        String nickName = user.getNickName();

        Map<String, Object> projectInfo = otherDataService.selectProjectInfo(commend.getBankCode());
        if (projectInfo != null) {
            saleCommendInfoPo.setProjectId(projectInfo.get("projectId") == null ? null : projectInfo.get("projectId").toString());
            saleCommendInfoPo.setProjectName(projectInfo.get("projectName") == null ? null : projectInfo.get("projectName").toString());
            saleCommendInfoPo.setSaleManagerId(projectInfo.get("saleManagerId") == null ? null : projectInfo.get("saleManagerId").toString());
            saleCommendInfoPo.setSaleManagerName(projectInfo.get("saleManagerName") == null ? null : projectInfo.get("saleManagerName").toString());
        }

        saleCommendInfoPo.setCreatedBy(nickName);
        saleCommendInfoPo.setPhone(phone);
        saleCommendInfoPo.setSubmitter(nickName);
        saleCommendInfoPo.setSubmitTime(LocalDateTime.now());

        saleCommendInfoService.saveOrUpdate(saleCommendInfoPo);

        return WrapMapper.ok("添加成功");
    }

}