package com.nh.farm.cloud.business.controller;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.nh.farm.cloud.basic.entity.UserEntity;
import com.nh.farm.cloud.business.domain.dto.SaleComplainInfoDto;
import com.nh.farm.cloud.business.domain.dto.SalePageQuery;
import com.nh.farm.cloud.business.domain.po.SaleComplainInfoPo;
import com.nh.farm.cloud.business.service.OtherDataService;
import com.nh.farm.cloud.business.service.SaleComplainInfoService;
import com.nh.farm.cloud.util.redis.TokenUtil;
import com.nh.fk.common.util.wrapper.WrapMapper;
import com.nh.fk.common.util.wrapper.Wrapper;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.Map;

/**
 * @description: 投诉建议
 * @author: suyun
 */
@RestController
@RequestMapping("complain")
public class SaleComplainController {

    @Autowired
    private TokenUtil tokenUtil;

    @Autowired
    private OtherDataService otherDataService;

    @Autowired
    private SaleComplainInfoService saleComplainInfoService;

    /**
     * 汇总
     */
    @GetMapping("/collectInfo")
    public Wrapper<Map<String, Object>> collectInfo(SalePageQuery pageQuery) {
        Map<String, Object> map = saleComplainInfoService.collectInfo(pageQuery);
        return WrapMapper.ok(map);
    }

    /**
     * 分页
     */
    @GetMapping("/selectInfo")
    public Wrapper<IPage<SaleComplainInfoPo>> selectInfo(SalePageQuery pageQuery) {
        IPage page = saleComplainInfoService.queryPage(pageQuery);
        return WrapMapper.ok(page);
    }

    /**
     * 新增
     */
    @Transactional
    @PostMapping("/saveInfo")
    public Wrapper<String> saveInfo(@RequestBody SaleComplainInfoDto complain){
        SaleComplainInfoPo saleComplainInfoPo = new SaleComplainInfoPo();
        BeanUtils.copyProperties(complain, saleComplainInfoPo);
        UserEntity user = tokenUtil.getUser();
        String phone = user.getPhone();
        String nickName = user.getNickName();

        Map<String, Object> projectInfo = otherDataService.selectProjectInfo(complain.getBankCode());
        if (projectInfo != null) {
            saleComplainInfoPo.setProjectId(projectInfo.get("projectId") == null ? null : projectInfo.get("projectId").toString());
            saleComplainInfoPo.setProjectName(projectInfo.get("projectName") == null ? null : projectInfo.get("projectName").toString());
            saleComplainInfoPo.setSaleManagerId(projectInfo.get("saleManagerId") == null ? null : projectInfo.get("saleManagerId").toString());
            saleComplainInfoPo.setSaleManagerName(projectInfo.get("saleManagerName") == null ? null : projectInfo.get("saleManagerName").toString());
        }

        saleComplainInfoPo.setCreatedBy(nickName);
        saleComplainInfoPo.setPhone(phone);
        saleComplainInfoPo.setSubmitter(nickName);
        saleComplainInfoPo.setSubmitTime(LocalDateTime.now());

        saleComplainInfoService.saveOrUpdate(saleComplainInfoPo);

        return WrapMapper.ok("添加成功");
    }

    /**
     * 状态变更
     */
    @PutMapping("/statusChange/{kid}")
    public Wrapper<String> statusChange(@PathVariable("kid") String kid){
        SaleComplainInfoPo complain = saleComplainInfoService.getById(kid);
        complain.setStatus(2);

        UpdateWrapper<SaleComplainInfoPo> updateWrapper = new UpdateWrapper<>();
        updateWrapper.lambda().eq(SaleComplainInfoPo::getKid, kid);
        boolean result = saleComplainInfoService.update(complain, updateWrapper);

        if (!result) {
            return WrapMapper.error("撤回失败");
        }

        return WrapMapper.ok("撤回成功");
    }

}