package com.nh.farm.cloud.business.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.nh.farm.cloud.basic.entity.UserEntity;
import com.nh.farm.cloud.business.domain.dto.SaleFeedbackInfoDto;
import com.nh.farm.cloud.business.domain.dto.SalePageQuery;
import com.nh.farm.cloud.business.domain.po.SaleFeedbackDetailPo;
import com.nh.farm.cloud.business.domain.po.SaleFeedbackInfoPo;
import com.nh.farm.cloud.business.service.SaleFeedbackDetailService;
import com.nh.farm.cloud.business.service.SaleFeedbackInfoService;
import com.nh.farm.cloud.util.redis.TokenUtil;
import com.nh.fk.common.util.wrapper.WrapMapper;
import com.nh.fk.common.util.wrapper.Wrapper;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * @description: 问题反馈
 * @author: suyun
 */
@RestController
@RequestMapping("feedback")
public class SaleFeedbackController {

    @Autowired
    private TokenUtil tokenUtil;
    
    @Autowired
    private SaleFeedbackInfoService saleFeedbackInfoService;

    @Autowired
    private SaleFeedbackDetailService saleFeedbackDetailService;

    /**
     * 汇总
     */
    @GetMapping("/collectInfo")
    public Wrapper<Map<String, Object>> collectInfo(SalePageQuery pageQuery) {
        Map<String, Object> map = saleFeedbackInfoService.collectInfo(pageQuery);
        return WrapMapper.ok(map);
    }

    /**
     * 按系统汇总
     */
    @GetMapping("/collectBySystem")
    public Wrapper<List<Map<String, Object>>> collectBySystem(SalePageQuery pageQuery) {
        List<Map<String, Object>> list = saleFeedbackInfoService.collectBySystem(pageQuery);
        return WrapMapper.ok(list);
    }

    /**
     * 分页
     */
    @GetMapping("/selectInfo")
    public Wrapper<IPage<SaleFeedbackInfoPo>> selectInfo(SalePageQuery pageQuery) {
        IPage page = saleFeedbackInfoService.queryPage(pageQuery);
        return WrapMapper.ok(page);
    }

    /**
     * 明细
     */
    @GetMapping("/getDetail")
    public Wrapper<List<SaleFeedbackDetailPo>> getDetail(SalePageQuery pageQuery) {
        List<SaleFeedbackDetailPo> list = saleFeedbackDetailService.getDetail(pageQuery);
        return WrapMapper.ok(list);
    }

    /**
     * 新增
     */
    @Transactional
    @PostMapping("/saveInfo")
    public Wrapper<JSONObject> saveInfo(@RequestBody SaleFeedbackInfoDto feedback){
        SaleFeedbackInfoPo saleFeedbackInfoPo = new SaleFeedbackInfoPo();
        BeanUtils.copyProperties(feedback, saleFeedbackInfoPo);
        UserEntity user = tokenUtil.getUser();
        String phone = user.getPhone();
        String nickName = user.getNickName();
        Integer status = feedback.getStatus();

        saleFeedbackInfoPo.setCreatedBy(nickName);

        JSONObject jsonObject = null;

        if (status == 1) {
            saleFeedbackInfoPo.setPhone(phone);
            saleFeedbackInfoPo.setSubmitter(nickName);
            saleFeedbackInfoPo.setSubmitTime(LocalDateTime.now());
        }

        saleFeedbackInfoService.saveOrUpdate(saleFeedbackInfoPo);

        return WrapMapper.ok(jsonObject);
    }

    /**
     * 删除
     */
    @DeleteMapping("/deleteInfo/{kid}")
    public Wrapper<String> deleteInfo(@PathVariable("kid") String kid){
        boolean b = saleFeedbackInfoService.removeById(kid);
        if(b) return WrapMapper.ok("删除成功");

        return WrapMapper.error("删除失败");
    }

}