package com.nh.farm.cloud.business.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.nh.farm.cloud.basic.entity.UserEntity;
import com.nh.farm.cloud.business.domain.dto.SalePageQuery;
import com.nh.farm.cloud.business.domain.dto.SaleSatisfactionBasicDto;
import com.nh.farm.cloud.business.domain.po.SaleFeedbackInfoPo;
import com.nh.farm.cloud.business.domain.po.SaleSatisfactionBasicPo;
import com.nh.farm.cloud.business.domain.po.SaleSatisfactionDetailPo;
import com.nh.farm.cloud.business.domain.po.SaleSatisfactionInfoPo;
import com.nh.farm.cloud.business.service.OtherDataService;
import com.nh.farm.cloud.business.service.SaleSatisfactionBasicService;
import com.nh.farm.cloud.business.service.SaleSatisfactionDetailService;
import com.nh.farm.cloud.business.service.SaleSatisfactionInfoService;
import com.nh.farm.cloud.util.redis.TokenUtil;
import com.nh.fk.common.util.wrapper.WrapMapper;
import com.nh.fk.common.util.wrapper.Wrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * @description: 满意度调查
 * @author: suyun
 */
@RestController
@RequestMapping("satisfaction")
public class SaleSatisfactionController {

    @Autowired
    private TokenUtil tokenUtil;

    @Autowired
    private OtherDataService otherDataService;

    @Autowired
    private SaleSatisfactionBasicService saleSatisfactionBasicService;

    @Autowired
    private SaleSatisfactionInfoService saleSatisfactionInfoService;

    @Autowired
    private SaleSatisfactionDetailService saleSatisfactionDetailService;

    /**
     * 获取 满意度调查配置 列表
     */
    @GetMapping("/selectBasicList")
    public Wrapper<List<SaleSatisfactionBasicPo>> selectBasicList() {
        List<SaleSatisfactionBasicPo> list = saleSatisfactionBasicService.selectBasicList();
        return WrapMapper.ok(list);
    }

    /**
     * 获取最新的 满意度调查配置
     */
    @GetMapping("/getLatestBasic")
    public Wrapper<SaleSatisfactionBasicPo> queryStatistics() {
        SaleSatisfactionBasicPo basic = saleSatisfactionBasicService.getLatestBasic();
        return WrapMapper.ok(basic);
    }

    /**
     * 满意度调查填写-分页
     */
    @GetMapping("/selectInfo")
    public Wrapper<IPage<SaleFeedbackInfoPo>> selectInfo(SalePageQuery pageQuery) {
        IPage page = saleSatisfactionInfoService.queryPage(pageQuery);
        return WrapMapper.ok(page);
    }

    /**
     * 满意度调查填写-明细
     */
    @GetMapping("/getInfoDetail")
    public Wrapper<SaleSatisfactionBasicPo> getDetail(SalePageQuery pageQuery) {
        SaleSatisfactionBasicPo basic = saleSatisfactionDetailService.getInfoDetail(pageQuery);
        return WrapMapper.ok(basic);
    }

    /**
     * 满意度调查填写-新增
     */
    @Transactional
    @PostMapping("/saveInfo")
    public Wrapper<String> saveInfo(@RequestBody SaleSatisfactionBasicDto satisfaction){
        SaleSatisfactionInfoPo satisfactionInfoPo = new SaleSatisfactionInfoPo();
        UserEntity user = tokenUtil.getUser();
        String phone = user.getPhone();
        String nickName = user.getNickName();

        Map<String, Object> projectInfo = otherDataService.selectProjectInfo(satisfaction.getBankCode());
        if (projectInfo != null) {
            satisfactionInfoPo.setProjectId(projectInfo.get("projectId") == null ? null : projectInfo.get("projectId").toString());
            satisfactionInfoPo.setProjectName(projectInfo.get("projectName") == null ? null : projectInfo.get("projectName").toString());
            satisfactionInfoPo.setSaleManagerId(projectInfo.get("saleManagerId") == null ? null : projectInfo.get("saleManagerId").toString());
            satisfactionInfoPo.setSaleManagerName(projectInfo.get("saleManagerName") == null ? null : projectInfo.get("saleManagerName").toString());
        }

        satisfactionInfoPo.setBankCode(satisfaction.getBankCode());
        satisfactionInfoPo.setBankName(satisfaction.getBankName());
        satisfactionInfoPo.setSatisfactionBasicId(satisfaction.getKid());
        satisfactionInfoPo.setSatisfactionBasicName(satisfaction.getName());
        satisfactionInfoPo.setScore(satisfaction.getScore());
        satisfactionInfoPo.setResult(satisfaction.getResult());
        satisfactionInfoPo.setRemark(satisfaction.getRemark());

        satisfactionInfoPo.setCreatedBy(nickName);
        satisfactionInfoPo.setPhone(phone);
        satisfactionInfoPo.setSubmitter(nickName);
        satisfactionInfoPo.setSubmitTime(LocalDateTime.now());

        // 第一层级：满意度调查名称
        saleSatisfactionInfoService.save(satisfactionInfoPo);

        // 第二层级：调查内容
        satisfaction.getDetail().forEach(entryTop -> {
            // 第三层级：考评指标
            entryTop.getDetail().forEach(entryPro -> {
                SaleSatisfactionDetailPo satisfactionDetailPo = new SaleSatisfactionDetailPo();
                satisfactionDetailPo.setSatisfactionInfoId(satisfactionInfoPo.getKid());
                satisfactionDetailPo.setIndexId(entryPro.getKid());
                satisfactionDetailPo.setIndexName(entryPro.getName());
                satisfactionDetailPo.setScore(entryPro.getScore());
                saleSatisfactionDetailService.save(satisfactionDetailPo);
            });
        });

        return WrapMapper.ok("操作成功");
    }

}