package com.nh.farm.cloud.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.nh.farm.cloud.business.domain.po.SaleSatisfactionBasicPo;
import com.nh.farm.cloud.business.mapper.SaleSatisfactionBasicMapper;
import com.nh.farm.cloud.business.service.SaleSatisfactionBasicService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @description: 满意度调查配置
 * @author: suyun
 */
@Slf4j
@Service
public class SaleSatisfactionBasicServiceImpl extends ServiceImpl<SaleSatisfactionBasicMapper, SaleSatisfactionBasicPo> implements SaleSatisfactionBasicService {

    @Override
    public List<SaleSatisfactionBasicPo> selectBasicList() {
        QueryWrapper<SaleSatisfactionBasicPo> wrapper = new QueryWrapper<>();
        wrapper.lambda().eq(SaleSatisfactionBasicPo::getSatisfactionLevel, 0);
        wrapper.lambda().orderByDesc(SaleSatisfactionBasicPo::getCreatedTime);
        List<SaleSatisfactionBasicPo> list = this.baseMapper.selectList(wrapper);
        return list;
    }

    @Override
    public SaleSatisfactionBasicPo getLatestBasic() {
        QueryWrapper<SaleSatisfactionBasicPo> wrapper = new QueryWrapper<>();
        wrapper.lambda().eq(SaleSatisfactionBasicPo::getSatisfactionLevel, 0);
        wrapper.lambda().orderByDesc(SaleSatisfactionBasicPo::getCreatedTime);
        List<SaleSatisfactionBasicPo> basicList  = this.baseMapper.selectList(wrapper);

        if (basicList.isEmpty()) {
            return null;
        } else {
            // 第一层级：满意度调查名称
            SaleSatisfactionBasicPo basic = basicList.get(0);
            // 第二层级：调查内容
            List<SaleSatisfactionBasicPo> topList = this.baseMapper.selectList(new LambdaQueryWrapper<SaleSatisfactionBasicPo>().eq(SaleSatisfactionBasicPo::getTopId, basic.getKid()));
            topList.forEach(top -> {
                // 第三层级：考评指标
                List<SaleSatisfactionBasicPo> proList = this.baseMapper.selectList(new LambdaQueryWrapper<SaleSatisfactionBasicPo>().eq(SaleSatisfactionBasicPo::getTopId, top.getKid()));
                top.setDetail(proList);
            });
            basic.setDetail(topList);
            return basic;
        }
    }

}
