package com.nh.farm.cloud.util;

import java.math.BigDecimal;

/**
 *	计算公式 .
 *
 */
public class BigDecimalUtil {
	/**
	 * 对double数据进行取精度.
	 * @param value  double数据.
	 * @param scale  精度位数(保留的小数位数).
	 * @param roundingMode  精度取值方式.
	 * @return 精度计算后的数据.
	 */
	public static double round(double value, int scale,
			int roundingMode) {
		BigDecimal bd = BigDecimal.valueOf(value);
		bd = bd.setScale(scale, roundingMode);
		double d = bd.doubleValue();
		bd = null;
		return d;
	}


	/**
	 *   提供精确的小数位四舍五入处理 .
	 *   @param   v   需要四舍五入的数字。
	 *   @param   scale   小数点后保留几位。
	 *   @return   四舍五入后的结果。
	 */
	public static BigDecimal round(BigDecimal v, 
			int scale) {
		if (scale < 0) {
			throw new IllegalArgumentException("The   scale   must   be   a   positive   integer   or   zero");
		}
		BigDecimal b = new BigDecimal(v.toString());
		BigDecimal one = new BigDecimal("1");
		return b.divide(one, scale, BigDecimal.ROUND_HALF_UP);
	}


	/**
	 * double 相加.
	 * @param d1
	 * @param d2
	 * @return
	 */
	public static BigDecimal sum(BigDecimal d1,BigDecimal d2){
		BigDecimal bd1 = new BigDecimal(d1.toString());
		BigDecimal bd2 = new BigDecimal(d2.toString()); 
		return bd1.add(bd2);
	}


	/**
	 * double 相减.
	 * @param d1
	 * @param d2
	 * @return
	 */
	public static BigDecimal sub(BigDecimal d1,BigDecimal d2){
		BigDecimal bd1 = new BigDecimal(d1.toString());
		BigDecimal bd2 = new BigDecimal(d2.toString());
		return bd1.subtract(bd2);
	}

	/**
	 * double 乘法.
	 * @param d1
	 * @param d2
	 * @return
	 */
	public static BigDecimal mul(BigDecimal d1,BigDecimal d2){
		BigDecimal bd1 = new BigDecimal(d1.toString());
		BigDecimal bd2 = new BigDecimal(d2.toString());
		return bd1.multiply(bd2);
	}

	/**
	 * double 乘法.
	 * @param d1
	 * @param d2
	 * @return
	 */
	public static BigDecimal mul(BigDecimal d1,BigDecimal d2,int scale){
		return round(mul(d1,d2), scale);
	}


	/**
	 * double 除法.
	 * @param d1
	 * @param d2
	 * @param scale 四舍五入 小数点位数
	 * @return
	 */
	public static BigDecimal div(BigDecimal d1,BigDecimal d2,int scale){
		//  当然在此之前，你要判断分母是否为0，
		//  为0你可以根据实际需求做相应的处理

		BigDecimal bd1 = new BigDecimal(d1.toString());
		BigDecimal bd2 = new BigDecimal(d2.toString());
		return bd1.divide
				(bd2,scale,BigDecimal.ROUND_HALF_UP);
	}

	/**
	 * double 除法.
	 * @param d1
	 * @param d2
	 * @param scale 小数点位数(向零方向舍入的舍入模式)
	 * @return
	 */
	public static BigDecimal divDown(BigDecimal d1,BigDecimal d2,int scale){
		//  当然在此之前，你要判断分母是否为0，
		//  为0你可以根据实际需求做相应的处理

		BigDecimal bd1 = new BigDecimal(d1.toString());
		BigDecimal bd2 = new BigDecimal(d2.toString());
		return bd1.divide
				(bd2,scale,BigDecimal.ROUND_DOWN);
	}


	/**
	 * 获取账套.
	 */
	public static String getBillTo(String costCenterCode) {
		if("BSVK".equals(costCenterCode.substring(0, 4))){
			return "8009";
		}else if("Bddd".equals(costCenterCode.substring(0, 4))){
			return "1001";
		}else{
			return "1301";
		}
	}
}
